==> libsvgo-1.3.2-dev.0.tgz: package/plugins/convertPathData.js <==
var t=require("../lib/svgo/tools")
var e=require("./_collections")
var s=require("./_path")
exports.name="convertPathData"
exports.type="perItem"
exports.active=!0
exports.description="optimizes path data: writes in shorter form, applies transformations"
exports.params={applyTransforms:!0,applyTransformsStroked:!0,makeArcs:{threshold:2.5,tolerance:.5},straightCurves:!0,lineShorthands:!0,curveSmoothShorthands:!0,floatPrecision:3,transformPrecision:5,removeUseless:!0,collapseRepeated:!0,utilizeAbsolute:!0,leadingZero:!0,negativeExtraSpace:!0,noSpaceAfterFlags:!0,forceAbsolutePath:!1}
let n
let a
let i
let o
let r
let c
let l
exports.fn=function(q,k){if(q.isElem(e.pathElems)&&q.hasAttr("d")){a=k.floatPrecision
i=!1!==a?+Math.pow(.1,a).toFixed(a):.01
n=a>0&&a<20?f:h
if(k.makeArcs){o=k.makeArcs.threshold
r=k.makeArcs.tolerance}c=q.hasAttr("marker-mid")
const e=q.computedAttr("stroke")
const O=q.computedAttr("stroke")
l=e&&"none"!==e&&O&&"butt"!==O
let S=(0,s.path2js)(q)
if(S.length){!function(t){const e=[0,0]
const s=[0,0]
let n
t.forEach((function(a,i){let o=a.instruction
const r=a.data
if(r){if("mcslqta".indexOf(o)>-1){e[0]+=r[r.length-2]
e[1]+=r[r.length-1]
if("m"===o){s[0]=e[0]
s[1]=e[1]
n=a}}else"h"===o?e[0]+=r[0]:"v"===o&&(e[1]+=r[0])
if("M"===o){i>0&&(o="m")
r[0]-=e[0]
r[1]-=e[1]
s[0]=e[0]+=r[0]
s[1]=e[1]+=r[1]
n=a}else if("LT".indexOf(o)>-1){o=o.toLowerCase()
r[0]-=e[0]
r[1]-=e[1]
e[0]+=r[0]
e[1]+=r[1]}else if("C"===o){o="c"
r[0]-=e[0]
r[1]-=e[1]
r[2]-=e[0]
r[3]-=e[1]
r[4]-=e[0]
r[5]-=e[1]
e[0]+=r[4]
e[1]+=r[5]}else if("SQ".indexOf(o)>-1){o=o.toLowerCase()
r[0]-=e[0]
r[1]-=e[1]
r[2]-=e[0]
r[3]-=e[1]
e[0]+=r[2]
e[1]+=r[3]}else if("A"===o){o="a"
r[5]-=e[0]
r[6]-=e[1]
e[0]+=r[5]
e[1]+=r[6]}else if("H"===o){o="h"
r[0]-=e[0]
e[0]+=r[0]}else if("V"===o){o="v"
r[0]-=e[1]
e[1]+=r[0]}a.instruction=o
a.data=r
a.coords=e.slice(-2)}else if("z"===o){n&&(a.coords=n.coords)
e[0]=s[0]
e[1]=s[1]}a.base=i>0?t[i-1].coords:[0,0]}))}(S)
k.applyTransforms&&(S=(0,s.applyTransforms)(q,S,k))
S=function(t,e){const s=A.bind(null,e)
const f=[0,0]
const h=[0,0]
let q={}
return t.filter((function(t,A,k){let O=t.instruction
let S=t.data
let y=k[A+1]
if(S){let P=S
let C
if("s"===O){P=[0,0].concat(S)
if("cs".indexOf(q.instruction)>-1){const t=q.data
const e=t.length
P[0]=t[e-2]-t[e-4]
P[1]=t[e-1]-t[e-3]}}if(e.makeArcs&&("c"===O||"s"===O)&&d(P)&&(C=function(t){const e=g(t,.5)
const s=[e[0]/2,e[1]/2]
const n=[(e[0]+t[4])/2,(e[1]+t[5])/2]
const a=u([s[0],s[1],s[0]+s[1],s[1]-s[0],n[0],n[1],n[0]+(n[1]-e[1]),n[1]-(n[0]-e[0])])
const c=a&&m([0,0],a)
const l=Math.min(o*i,r*c/100)
if(a&&c<1e15&&[1/4,3/4].every((function(e){return Math.abs(m(g(t,e),a)-c)<=l})))return{center:a,radius:c}}(P))){let e
const a=n([C.radius])[0]
let i=M(P,C)
const o=P[5]*P[0]-P[4]*P[1]>0?1:0
let r={instruction:"a",data:[a,a,0,0,o,P[4],P[5]],coords:t.coords.slice(),base:t.base}
const c=[r]
const l=[C.center[0]-P[4],C.center[1]-P[5]]
const u={center:l,radius:C.radius}
const h=[t]
let p=0
let m=""
let g
if("c"===q.instruction&&d(q.data)&&x(q.data,C)||"a"===q.instruction&&q.sdata&&x(q.sdata,C)){h.unshift(q)
r.base=q.base
r.data[5]=r.coords[0]-r.base[0]
r.data[6]=r.coords[1]-r.base[1]
const t="a"===q.instruction?q.sdata:q.data
i+=M(t,{center:[t[4]+C.center[0],t[5]+C.center[1]],radius:C.radius})
i>Math.PI&&(r.data[3]=1)
p=1}for(e=A;(y=k[++e])&&~"cs".indexOf(y.instruction);){let t=y.data
if("s"===y.instruction){g=b({instruction:"s",data:y.data.slice()},k[e-1].data)
t=g.data
g.data=t.slice(0,2)
m=s([g])}if(!d(t)||!v(t,u))break
i+=M(t,u)
if(i-2*Math.PI>.001)break
i>Math.PI&&(r.data[3]=1)
h.push(y)
if(!(2*Math.PI-i>.001)){r.data[5]=2*(u.center[0]-t[4])
r.data[6]=2*(u.center[1]-t[5])
r.coords=[r.base[0]+r.data[5],r.base[1]+r.data[6]]
r={instruction:"a",data:[a,a,0,0,o,y.coords[0]-r.coords[0],y.coords[1]-r.coords[1]],coords:y.coords,base:r.coords}
c.push(r)
e++
break}r.coords=y.coords
r.data[5]=r.coords[0]-r.base[0]
r.data[6]=r.coords[1]-r.base[1]
l[0]-=t[4]
l[1]-=t[5]}if((s(c)+m).length<s(h).length){k[e]&&"s"===k[e].instruction&&b(k[e],k[e-1].data)
if(p){const e=c.shift()
n(e.data)
f[0]+=e.data[5]-q.data[q.data.length-2]
f[1]+=e.data[6]-q.data[q.data.length-1]
q.instruction="a"
q.data=e.data
t.base=q.coords=e.coords}r=c.shift()
1===h.length?t.sdata=P.slice():h.length-1-p>0&&k.splice.apply(k,[A+1,h.length-1-p].concat(c))
if(!r)return!1
O="a"
S=r.data
t.coords=r.coords}}if(!1!==a){if("mltqsc".indexOf(O)>-1)for(let e=S.length;e--;)S[e]+=t.base[e%2]-f[e%2]
else if("h"===O)S[0]+=t.base[0]-f[0]
else if("v"===O)S[0]+=t.base[1]-f[1]
else if("a"===O){S[5]+=t.base[0]-f[0]
S[6]+=t.base[1]-f[1]}n(S)
if("h"===O)f[0]+=S[0]
else if("v"===O)f[1]+=S[0]
else{f[0]+=S[S.length-2]
f[1]+=S[S.length-1]}n(f)
if("m"===O.toLowerCase()){h[0]=f[0]
h[1]=f[1]}}if(e.straightCurves)if("c"===O&&p(S)||"s"===O&&p(P)){y&&"s"===y.instruction&&b(y,S)
O="l"
S=S.slice(-2)}else if("q"===O&&p(S)){y&&"t"===y.instruction&&b(y,S)
O="l"
S=S.slice(-2)}else if("t"===O&&"q"!==q.instruction&&"t"!==q.instruction){O="l"
S=S.slice(-2)}else if("a"===O&&(0===S[0]||0===S[1])){O="l"
S=S.slice(-2)}if(e.lineShorthands&&"l"===O)if(0===S[1]){O="h"
S.pop()}else if(0===S[0]){O="v"
S.shift()}if(e.collapseRepeated&&!c&&"mhv".indexOf(O)>-1&&q.instruction&&O===q.instruction.toLowerCase()&&("h"!==O&&"v"!==O||q.data[0]>=0==S[0]>=0)){q.data[0]+=S[0]
"h"!==O&&"v"!==O&&(q.data[1]+=S[1])
q.coords=t.coords
k[A]=q
return!1}if(e.curveSmoothShorthands&&q.instruction)if("c"===O){if("c"===q.instruction&&S[0]===-(q.data[2]-q.data[4])&&S[1]===-(q.data[3]-q.data[5])){O="s"
S=S.slice(2)}else if("s"===q.instruction&&S[0]===-(q.data[0]-q.data[2])&&S[1]===-(q.data[1]-q.data[3])){O="s"
S=S.slice(2)}else if(-1==="cs".indexOf(q.instruction)&&0===S[0]&&0===S[1]){O="s"
S=S.slice(2)}}else if("q"===O)if("q"===q.instruction&&S[0]===q.data[2]-q.data[0]&&S[1]===q.data[3]-q.data[1]){O="t"
S=S.slice(2)}else if("t"===q.instruction&&S[2]===q.data[0]&&S[3]===q.data[1]){O="t"
S=S.slice(2)}if(e.removeUseless&&!l){if("lhvqtcs".indexOf(O)>-1&&S.every((function(t){return 0===t}))){k[A]=q
return!1}if("a"===O&&0===S[5]&&0===S[6]){k[A]=q
return!1}}t.instruction=O
t.data=S
q=t}else{f[0]=h[0]
f[1]=h[1]
if("z"===q.instruction)return!1
q=t}return!0}))}(S,k)
k.utilizeAbsolute&&(S=function(e,s){let a=e[0]
return e.filter((function(e,i){if(0===i)return!0
if(!e.data){a=e
return!0}const o=e.instruction
const r=e.data
const c=r&&r.slice(0)
if("mltqsc".indexOf(o)>-1)for(let t=c.length;t--;)c[t]+=e.base[t%2]
else if("h"===o)c[0]+=e.base[0]
else if("v"===o)c[0]+=e.base[1]
else if("a"===o){c[5]+=e.base[0]
c[6]+=e.base[1]}n(c)
const l=(0,t.cleanupOutData)(c,s)
const d=(0,t.cleanupOutData)(r,s)
if(s.forceAbsolutePath||l.length<d.length&&!(s.negativeExtraSpace&&o===a.instruction&&a.instruction.charCodeAt(0)>96&&l.length===d.length-1&&(r[0]<0||/^0\./.test(r[0])&&a.data[a.data.length-1]%1))){e.instruction=o.toUpperCase()
e.data=c}a=e
return!0}))}(S,k));(0,s.js2path)(q,S,k)}}}
function d(t){const e=u([0,0,t[2],t[3],t[0],t[1],t[4],t[5]])
return e&&t[2]<e[0]==e[0]<0&&t[3]<e[1]==e[1]<0&&t[4]<e[0]==e[0]<t[0]&&t[5]<e[1]==e[1]<t[1]}function u(t){const e=t[1]-t[3]
const s=t[2]-t[0]
const n=t[0]*t[3]-t[2]*t[1]
const a=t[5]-t[7]
const i=t[6]-t[4]
const o=t[4]*t[7]-t[5]*t[6]
const r=e*i-a*s
if(!r)return
const c=[(s*o-i*n)/r,(e*o-a*n)/-r]
return!isNaN(c[0])&&!isNaN(c[1])&&isFinite(c[0])&&isFinite(c[1])?c:void 0}function f(t){for(let e=t.length;e-- >0;)if(t[e].toFixed(a)!==t[e]){const s=+t[e].toFixed(a-1)
t[e]=+Math.abs(s-t[e]).toFixed(a+1)>=i?+t[e].toFixed(a):s}return t}function h(t){for(let e=t.length;e-- >0;)t[e]=Math.round(t[e])
return t}function p(t){let e=t.length-2
const s=-t[e+1]
const n=t[e]
const a=1/(s*s+n*n)
if(e<=1||!isFinite(a))return!1
for(;(e-=2)>=0;)if(Math.sqrt(Math.pow(s*t[e]+n*t[e+1],2)*a)>i)return!1
return!0}function b(t,e){switch(t.instruction){case"s":t.instruction="c"
break
case"t":t.instruction="q"}t.data.unshift(e[e.length-2]-e[e.length-4],e[e.length-1]-e[e.length-3])
return t}function m(t,e){return Math.hypot(t[0]-e[0],t[1]-e[1])}function g(t,e){const s=e*e
const n=s*e
const a=1-e
const i=a*a
return[3*i*e*t[0]+3*a*s*t[2]+n*t[4],3*i*e*t[1]+3*a*s*t[3]+n*t[5]]}function v(t,e){const s=Math.min(o*i,r*e.radius/100)
return[0,1/4,.5,3/4,1].every((function(n){return Math.abs(m(g(t,n),e.center)-e.radius)<=s}))}function x(t,e){return v(t,{center:[e.center[0]+t[4],e.center[1]+t[5]],radius:e.radius})}function M(t,e){const s=-e.center[0]
const n=-e.center[1]
const a=t[4]-e.center[0]
const i=t[5]-e.center[1]
return Math.acos((s*a+n*i)/Math.sqrt((s*s+n*n)*(a*a+i*i)))}function A(e,s){return s.reduce((function(s,a){let i=""
a.data&&(i=(0,t.cleanupOutData)(n(a.data.slice()),e))
return s+a.instruction+i}),"")}

==> libsvgo-1.3.3.tgz: package/plugins/convertPathData.js <==
"use strict"
Object.defineProperty(exports,"__esModule",{value:!0})
exports.fn=exports.params=exports.description=exports.active=exports.type=exports.name=void 0
var t=require("../lib/svgo/tools")
var e=require("./_collections")
var s=require("./_path")
exports.name="convertPathData"
exports.type="perItem"
exports.active=!0
exports.description="optimizes path data: writes in shorter form, applies transformations"
exports.params={applyTransforms:!0,applyTransformsStroked:!0,makeArcs:{threshold:2.5,tolerance:.5},straightCurves:!0,lineShorthands:!0,curveSmoothShorthands:!0,floatPrecision:3,transformPrecision:5,removeUseless:!0,collapseRepeated:!0,utilizeAbsolute:!0,leadingZero:!0,negativeExtraSpace:!0,noSpaceAfterFlags:!0,forceAbsolutePath:!1}
let n
let a
let i
let o
let r
let c
let l
exports.fn=function(q,O){if(q.isElem(e.pathElems)&&q.hasAttr("d")){a=O.floatPrecision
i=!1!==a?+Math.pow(.1,a).toFixed(a):.01
n=a>0&&a<20?f:h
if(O.makeArcs){o=O.makeArcs.threshold
r=O.makeArcs.tolerance}c=q.hasAttr("marker-mid")
const e=q.computedAttr("stroke")
const k=q.computedAttr("stroke")
l=e&&"none"!==e&&k&&"butt"!==k
let y=(0,s.path2js)(q)
if(y.length){!function(t){const e=[0,0]
const s=[0,0]
let n
t.forEach((function(a,i){let o=a.instruction
const r=a.data
if(r){if("mcslqta".indexOf(o)>-1){e[0]+=r[r.length-2]
e[1]+=r[r.length-1]
if("m"===o){s[0]=e[0]
s[1]=e[1]
n=a}}else"h"===o?e[0]+=r[0]:"v"===o&&(e[1]+=r[0])
if("M"===o){i>0&&(o="m")
r[0]-=e[0]
r[1]-=e[1]
s[0]=e[0]+=r[0]
s[1]=e[1]+=r[1]
n=a}else if("LT".indexOf(o)>-1){o=o.toLowerCase()
r[0]-=e[0]
r[1]-=e[1]
e[0]+=r[0]
e[1]+=r[1]}else if("C"===o){o="c"
r[0]-=e[0]
r[1]-=e[1]
r[2]-=e[0]
r[3]-=e[1]
r[4]-=e[0]
r[5]-=e[1]
e[0]+=r[4]
e[1]+=r[5]}else if("SQ".indexOf(o)>-1){o=o.toLowerCase()
r[0]-=e[0]
r[1]-=e[1]
r[2]-=e[0]
r[3]-=e[1]
e[0]+=r[2]
e[1]+=r[3]}else if("A"===o){o="a"
r[5]-=e[0]
r[6]-=e[1]
e[0]+=r[5]
e[1]+=r[6]}else if("H"===o){o="h"
r[0]-=e[0]
e[0]+=r[0]}else if("V"===o){o="v"
r[0]-=e[1]
e[1]+=r[0]}a.instruction=o
a.data=r
a.coords=e.slice(-2)}else if("z"===o){n&&(a.coords=n.coords)
e[0]=s[0]
e[1]=s[1]}a.base=i>0?t[i-1].coords:[0,0]}))}(y)
O.applyTransforms&&(y=(0,s.applyTransforms)(q,y,O))
y=function(t,e){const s=A.bind(null,e)
const f=[0,0]
const h=[0,0]
let q={}
return t.filter((function(t,A,O){let k=t.instruction
let y=t.data
let P=O[A+1]
if(y){let S=y
let C
if("s"===k){S=[0,0].concat(y)
if("cs".indexOf(q.instruction)>-1){const t=q.data
const e=t.length
S[0]=t[e-2]-t[e-4]
S[1]=t[e-1]-t[e-3]}}if(e.makeArcs&&("c"===k||"s"===k)&&d(S)&&(C=function(t){const e=g(t,.5)
const s=[e[0]/2,e[1]/2]
const n=[(e[0]+t[4])/2,(e[1]+t[5])/2]
const a=u([s[0],s[1],s[0]+s[1],s[1]-s[0],n[0],n[1],n[0]+(n[1]-e[1]),n[1]-(n[0]-e[0])])
const c=a&&m([0,0],a)
const l=Math.min(o*i,r*c/100)
if(a&&c<1e15&&[1/4,3/4].every((function(e){return Math.abs(m(g(t,e),a)-c)<=l})))return{center:a,radius:c}}(S))){let e
const a=n([C.radius])[0]
let i=M(S,C)
const o=S[5]*S[0]-S[4]*S[1]>0?1:0
let r={instruction:"a",data:[a,a,0,0,o,S[4],S[5]],coords:t.coords.slice(),base:t.base}
const c=[r]
const l=[C.center[0]-S[4],C.center[1]-S[5]]
const u={center:l,radius:C.radius}
const h=[t]
let p=0
let m=""
let g
if("c"===q.instruction&&d(q.data)&&x(q.data,C)||"a"===q.instruction&&q.sdata&&x(q.sdata,C)){h.unshift(q)
r.base=q.base
r.data[5]=r.coords[0]-r.base[0]
r.data[6]=r.coords[1]-r.base[1]
const t="a"===q.instruction?q.sdata:q.data
i+=M(t,{center:[t[4]+C.center[0],t[5]+C.center[1]],radius:C.radius})
i>Math.PI&&(r.data[3]=1)
p=1}for(e=A;(P=O[++e])&&~"cs".indexOf(P.instruction);){let t=P.data
if("s"===P.instruction){g=b({instruction:"s",data:P.data.slice()},O[e-1].data)
t=g.data
g.data=t.slice(0,2)
m=s([g])}if(!d(t)||!v(t,u))break
i+=M(t,u)
if(i-2*Math.PI>.001)break
i>Math.PI&&(r.data[3]=1)
h.push(P)
if(!(2*Math.PI-i>.001)){r.data[5]=2*(u.center[0]-t[4])
r.data[6]=2*(u.center[1]-t[5])
r.coords=[r.base[0]+r.data[5],r.base[1]+r.data[6]]
r={instruction:"a",data:[a,a,0,0,o,P.coords[0]-r.coords[0],P.coords[1]-r.coords[1]],coords:P.coords,base:r.coords}
c.push(r)
e++
break}r.coords=P.coords
r.data[5]=r.coords[0]-r.base[0]
r.data[6]=r.coords[1]-r.base[1]
l[0]-=t[4]
l[1]-=t[5]}if((s(c)+m).length<s(h).length){O[e]&&"s"===O[e].instruction&&b(O[e],O[e-1].data)
if(p){const e=c.shift()
n(e.data)
f[0]+=e.data[5]-q.data[q.data.length-2]
f[1]+=e.data[6]-q.data[q.data.length-1]
q.instruction="a"
q.data=e.data
t.base=q.coords=e.coords}r=c.shift()
1===h.length?t.sdata=S.slice():h.length-1-p>0&&O.splice.apply(O,[A+1,h.length-1-p].concat(c))
if(!r)return!1
k="a"
y=r.data
t.coords=r.coords}}if(!1!==a){if("mltqsc".indexOf(k)>-1)for(let e=y.length;e--;)y[e]+=t.base[e%2]-f[e%2]
else if("h"===k)y[0]+=t.base[0]-f[0]
else if("v"===k)y[0]+=t.base[1]-f[1]
else if("a"===k){y[5]+=t.base[0]-f[0]
y[6]+=t.base[1]-f[1]}n(y)
if("h"===k)f[0]+=y[0]
else if("v"===k)f[1]+=y[0]
else{f[0]+=y[y.length-2]
f[1]+=y[y.length-1]}n(f)
if("m"===k.toLowerCase()){h[0]=f[0]
h[1]=f[1]}}if(e.straightCurves)if("c"===k&&p(y)||"s"===k&&p(S)){P&&"s"===P.instruction&&b(P,y)
k="l"
y=y.slice(-2)}else if("q"===k&&p(y)){P&&"t"===P.instruction&&b(P,y)
k="l"
y=y.slice(-2)}else if("t"===k&&"q"!==q.instruction&&"t"!==q.instruction){k="l"
y=y.slice(-2)}else if("a"===k&&(0===y[0]||0===y[1])){k="l"
y=y.slice(-2)}if(e.lineShorthands&&"l"===k)if(0===y[1]){k="h"
y.pop()}else if(0===y[0]){k="v"
y.shift()}if(e.collapseRepeated&&!c&&"mhv".indexOf(k)>-1&&q.instruction&&k===q.instruction.toLowerCase()&&("h"!==k&&"v"!==k||q.data[0]>=0==y[0]>=0)){q.data[0]+=y[0]
"h"!==k&&"v"!==k&&(q.data[1]+=y[1])
q.coords=t.coords
O[A]=q
return!1}if(e.curveSmoothShorthands&&q.instruction)if("c"===k){if("c"===q.instruction&&y[0]===-(q.data[2]-q.data[4])&&y[1]===-(q.data[3]-q.data[5])){k="s"
y=y.slice(2)}else if("s"===q.instruction&&y[0]===-(q.data[0]-q.data[2])&&y[1]===-(q.data[1]-q.data[3])){k="s"
y=y.slice(2)}else if(-1==="cs".indexOf(q.instruction)&&0===y[0]&&0===y[1]){k="s"
y=y.slice(2)}}else if("q"===k)if("q"===q.instruction&&y[0]===q.data[2]-q.data[0]&&y[1]===q.data[3]-q.data[1]){k="t"
y=y.slice(2)}else if("t"===q.instruction&&y[2]===q.data[0]&&y[3]===q.data[1]){k="t"
y=y.slice(2)}if(e.removeUseless&&!l){if("lhvqtcs".indexOf(k)>-1&&y.every((function(t){return 0===t}))){O[A]=q
return!1}if("a"===k&&0===y[5]&&0===y[6]){O[A]=q
return!1}}t.instruction=k
t.data=y
q=t}else{f[0]=h[0]
f[1]=h[1]
if("z"===q.instruction)return!1
q=t}return!0}))}(y,O)
O.utilizeAbsolute&&(y=function(e,s){let a=e[0]
return e.filter((function(e,i){if(0===i)return!0
if(!e.data){a=e
return!0}const o=e.instruction
const r=e.data
const c=r&&r.slice(0)
if("mltqsc".indexOf(o)>-1)for(let t=c.length;t--;)c[t]+=e.base[t%2]
else if("h"===o)c[0]+=e.base[0]
else if("v"===o)c[0]+=e.base[1]
else if("a"===o){c[5]+=e.base[0]
c[6]+=e.base[1]}n(c)
const l=(0,t.cleanupOutData)(c,s)
const d=(0,t.cleanupOutData)(r,s)
if(s.forceAbsolutePath||l.length<d.length&&!(s.negativeExtraSpace&&o===a.instruction&&a.instruction.charCodeAt(0)>96&&l.length===d.length-1&&(r[0]<0||/^0\./.test(r[0])&&a.data[a.data.length-1]%1))){e.instruction=o.toUpperCase()
e.data=c}a=e
return!0}))}(y,O));(0,s.js2path)(q,y,O)}}}
function d(t){const e=u([0,0,t[2],t[3],t[0],t[1],t[4],t[5]])
return e&&t[2]<e[0]==e[0]<0&&t[3]<e[1]==e[1]<0&&t[4]<e[0]==e[0]<t[0]&&t[5]<e[1]==e[1]<t[1]}function u(t){const e=t[1]-t[3]
const s=t[2]-t[0]
const n=t[0]*t[3]-t[2]*t[1]
const a=t[5]-t[7]
const i=t[6]-t[4]
const o=t[4]*t[7]-t[5]*t[6]
const r=e*i-a*s
if(!r)return
const c=[(s*o-i*n)/r,(e*o-a*n)/-r]
return!isNaN(c[0])&&!isNaN(c[1])&&isFinite(c[0])&&isFinite(c[1])?c:void 0}function f(t){for(let e=t.length;e-- >0;)if(t[e].toFixed(a)!==t[e]){const s=+t[e].toFixed(a-1)
t[e]=+Math.abs(s-t[e]).toFixed(a+1)>=i?+t[e].toFixed(a):s}return t}function h(t){for(let e=t.length;e-- >0;)t[e]=Math.round(t[e])
return t}function p(t){let e=t.length-2
const s=-t[e+1]
const n=t[e]
const a=1/(s*s+n*n)
if(e<=1||!isFinite(a))return!1
for(;(e-=2)>=0;)if(Math.sqrt(Math.pow(s*t[e]+n*t[e+1],2)*a)>i)return!1
return!0}function b(t,e){switch(t.instruction){case"s":t.instruction="c"
break
case"t":t.instruction="q"}t.data.unshift(e[e.length-2]-e[e.length-4],e[e.length-1]-e[e.length-3])
return t}function m(t,e){return Math.hypot(t[0]-e[0],t[1]-e[1])}function g(t,e){const s=e*e
const n=s*e
const a=1-e
const i=a*a
return[3*i*e*t[0]+3*a*s*t[2]+n*t[4],3*i*e*t[1]+3*a*s*t[3]+n*t[5]]}function v(t,e){const s=Math.min(o*i,r*e.radius/100)
return[0,1/4,.5,3/4,1].every((function(n){return Math.abs(m(g(t,n),e.center)-e.radius)<=s}))}function x(t,e){return v(t,{center:[e.center[0]+t[4],e.center[1]+t[5]],radius:e.radius})}function M(t,e){const s=-e.center[0]
const n=-e.center[1]
const a=t[4]-e.center[0]
const i=t[5]-e.center[1]
return Math.acos((s*a+n*i)/Math.sqrt((s*s+n*n)*(a*a+i*i)))}function A(e,s){return s.reduce((function(s,a){let i=""
a.data&&(i=(0,t.cleanupOutData)(n(a.data.slice()),e))
return s+a.instruction+i}),"")}
